==> AEngine-1.0.6.tar.gz: AEngine-1.0.6/setup.py <==
# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['aengine']

package_data = \
{'': ['*'],
 'aengine': ['.git/*',
             '.git/hooks/*',
             '.git/info/*',
             '.git/logs/*',
             '.git/logs/refs/heads/*',
             '.git/logs/refs/remotes/origin/*',
             '.git/objects/0a/*',
             '.git/objects/0b/*',
             '.git/objects/0d/*',
             '.git/objects/0e/*',
             '.git/objects/0f/*',
             '.git/objects/10/*',
             '.git/objects/18/*',
             '.git/objects/19/*',
             '.git/objects/1a/*',
             '.git/objects/22/*',
             '.git/objects/23/*',
             '.git/objects/24/*',
             '.git/objects/29/*',
             '.git/objects/2a/*',
             '.git/objects/2d/*',
             '.git/objects/2f/*',
             '.git/objects/30/*',
             '.git/objects/31/*',
             '.git/objects/34/*',
             '.git/objects/36/*',
             '.git/objects/37/*',
             '.git/objects/38/*',
             '.git/objects/39/*',
             '.git/objects/3b/*',
             '.git/objects/41/*',
             '.git/objects/43/*',
             '.git/objects/46/*',
             '.git/objects/47/*',
             '.git/objects/48/*',
             '.git/objects/49/*',
             '.git/objects/4b/*',
             '.git/objects/4c/*',
             '.git/objects/4e/*',
             '.git/objects/50/*',
             '.git/objects/51/*',
             '.git/objects/52/*',
             '.git/objects/56/*',
             '.git/objects/57/*',
             '.git/objects/5b/*',
             '.git/objects/5c/*',
             '.git/objects/60/*',
             '.git/objects/66/*',
             '.git/objects/68/*',
             '.git/objects/6b/*',
             '.git/objects/6c/*',
             '.git/objects/6d/*',
             '.git/objects/6e/*',
             '.git/objects/6f/*',
             '.git/objects/71/*',
             '.git/objects/73/*',
             '.git/objects/75/*',
             '.git/objects/79/*',
             '.git/objects/7a/*',
             '.git/objects/7c/*',
             '.git/objects/7d/*',
             '.git/objects/80/*',
             '.git/objects/87/*',
             '.git/objects/89/*',
             '.git/objects/8c/*',
             '.git/objects/8d/*',
             '.git/objects/92/*',
             '.git/objects/95/*',
             '.git/objects/96/*',
             '.git/objects/97/*',
             '.git/objects/98/*',
             '.git/objects/9a/*',
             '.git/objects/9b/*',
             '.git/objects/9c/*',
             '.git/objects/a7/*',
             '.git/objects/a8/*',
             '.git/objects/ad/*',
             '.git/objects/af/*',
             '.git/objects/b3/*',
             '.git/objects/b4/*',
             '.git/objects/b6/*',
             '.git/objects/bc/*',
             '.git/objects/be/*',
             '.git/objects/c3/*',
             '.git/objects/c4/*',
             '.git/objects/c7/*',
             '.git/objects/cc/*',
             '.git/objects/d1/*',
             '.git/objects/d3/*',
             '.git/objects/d8/*',
             '.git/objects/d9/*',
             '.git/objects/e1/*',
             '.git/objects/e4/*',
             '.git/objects/e5/*',
             '.git/objects/e7/*',
             '.git/objects/ee/*',
             '.git/objects/f1/*',
             '.git/objects/f8/*',
             '.git/objects/f9/*',
             '.git/objects/fc/*',
             '.git/objects/pack/*',
             '.git/refs/heads/*',
             '.git/refs/remotes/origin/*',
             'alphabet/*']}

setup_kwargs = {
    'name': 'aengine',
    'version': '1.0.6',
    'description': 'Console applications Engine',
    'long_description': None,
    'author': 'alex',
    'author_email': None,
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)

==> AEngine-1.0.8.tar.gz: AEngine-1.0.8/setup.py <==
# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['aengine']

package_data = \
{'': ['*'],
 'aengine': ['.git/*',
             '.git/hooks/*',
             '.git/info/*',
             '.git/logs/*',
             '.git/logs/refs/heads/*',
             '.git/logs/refs/remotes/origin/*',
             '.git/objects/00/*',
             '.git/objects/03/*',
             '.git/objects/05/*',
             '.git/objects/0a/*',
             '.git/objects/0b/*',
             '.git/objects/0c/*',
             '.git/objects/0d/*',
             '.git/objects/0e/*',
             '.git/objects/0f/*',
             '.git/objects/10/*',
             '.git/objects/13/*',
             '.git/objects/17/*',
             '.git/objects/18/*',
             '.git/objects/19/*',
             '.git/objects/1a/*',
             '.git/objects/1b/*',
             '.git/objects/1c/*',
             '.git/objects/1e/*',
             '.git/objects/22/*',
             '.git/objects/23/*',
             '.git/objects/24/*',
             '.git/objects/25/*',
             '.git/objects/27/*',
             '.git/objects/28/*',
             '.git/objects/29/*',
             '.git/objects/2a/*',
             '.git/objects/2d/*',
             '.git/objects/2f/*',
             '.git/objects/30/*',
             '.git/objects/31/*',
             '.git/objects/34/*',
             '.git/objects/36/*',
             '.git/objects/37/*',
             '.git/objects/38/*',
             '.git/objects/39/*',
             '.git/objects/3b/*',
             '.git/objects/3c/*',
             '.git/objects/41/*',
             '.git/objects/43/*',
             '.git/objects/46/*',
             '.git/objects/47/*',
             '.git/objects/48/*',
             '.git/objects/49/*',
             '.git/objects/4a/*',
             '.git/objects/4b/*',
             '.git/objects/4c/*',
             '.git/objects/4e/*',
             '.git/objects/50/*',
             '.git/objects/51/*',
             '.git/objects/52/*',
             '.git/objects/54/*',
             '.git/objects/56/*',
             '.git/objects/57/*',
             '.git/objects/5b/*',
             '.git/objects/5c/*',
             '.git/objects/5e/*',
             '.git/objects/60/*',
             '.git/objects/65/*',
             '.git/objects/66/*',
             '.git/objects/68/*',
             '.git/objects/6b/*',
             '.git/objects/6c/*',
             '.git/objects/6d/*',
             '.git/objects/6e/*',
             '.git/objects/6f/*',
             '.git/objects/71/*',
             '.git/objects/73/*',
             '.git/objects/75/*',
             '.git/objects/79/*',
             '.git/objects/7a/*',
             '.git/objects/7c/*',
             '.git/objects/7d/*',
             '.git/objects/80/*',
             '.git/objects/83/*',
             '.git/objects/87/*',
             '.git/objects/89/*',
             '.git/objects/8c/*',
             '.git/objects/8d/*',
             '.git/objects/92/*',
             '.git/objects/95/*',
             '.git/objects/96/*',
             '.git/objects/97/*',
             '.git/objects/98/*',
             '.git/objects/9a/*',
             '.git/objects/9b/*',
             '.git/objects/9c/*',
             '.git/objects/9e/*',
             '.git/objects/a7/*',
             '.git/objects/a8/*',
             '.git/objects/ad/*',
             '.git/objects/af/*',
             '.git/objects/b1/*',
             '.git/objects/b3/*',
             '.git/objects/b4/*',
             '.git/objects/b6/*',
             '.git/objects/b9/*',
             '.git/objects/bc/*',
             '.git/objects/be/*',
             '.git/objects/c3/*',
             '.git/objects/c4/*',
             '.git/objects/c7/*',
             '.git/objects/cc/*',
             '.git/objects/ce/*',
             '.git/objects/d1/*',
             '.git/objects/d3/*',
             '.git/objects/d8/*',
             '.git/objects/d9/*',
             '.git/objects/dc/*',
             '.git/objects/dd/*',
             '.git/objects/e1/*',
             '.git/objects/e2/*',
             '.git/objects/e4/*',
             '.git/objects/e5/*',
             '.git/objects/e6/*',
             '.git/objects/e7/*',
             '.git/objects/e8/*',
             '.git/objects/ee/*',
             '.git/objects/ef/*',
             '.git/objects/f1/*',
             '.git/objects/f7/*',
             '.git/objects/f8/*',
             '.git/objects/f9/*',
             '.git/objects/fc/*',
             '.git/objects/pack/*',
             '.git/refs/heads/*',
             '.git/refs/remotes/origin/*',
             'alphabet/*',
             'templates/*']}

setup_kwargs = {
    'name': 'aengine',
    'version': '1.0.8',
    'description': 'Console applications Engine',
    'long_description': None,
    'author': 'alex',
    'author_email': None,
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
